@@ -2,7 +2,7 @@
 ** FontWriter.cpp                                                       **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2021 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -128,7 +128,7 @@ struct SFDActions : Glyph::IterationActions {
 	}
 
 	ostream &_os;
-   Glyph::Point _startPoint, _currentPoint;
+	Glyph::Point _startPoint, _currentPoint;
 };
 
 
@@ -174,8 +174,12 @@ static void writeSFD (const string &sfdname, const PhysicalFont &font, const set
 			"SplineSet\n";
 		Glyph glyph;
 		if (font.getGlyph(c, glyph, cb)) {
-			SFDActions actions(sfd);
-			glyph.iterate(actions, false);
+			if (glyph.empty())
+				sfd << "0 0 m 0\n";
+			else {
+				SFDActions actions(sfd);
+				glyph.iterate(actions, false);
+			}
 		}
 		sfd <<
 			"EndSplineSet\n"
