@@ -72,7 +72,7 @@ void SVGTree::setBBox (const BoundingBox &bbox) {
 		_root->addAttribute("width", XMLString(bbox.width()*ZOOM_FACTOR)+"pt");
 		_root->addAttribute("height", XMLString(bbox.height()*ZOOM_FACTOR)+"pt");
 	}
-	_root->addAttribute("viewBox", bbox.toSVGViewBox());
+	_root->addAttribute("viewBox", bbox.svgViewBoxString());
 }
 
 
@@ -92,7 +92,7 @@ void SVGTree::setFont (int num, const Font &font) {
 
 
 bool SVGTree::setFontFormat (string formatstr) {
-	size_t pos = formatstr.find(',');
+	auto pos = formatstr.find(',');
 	string opt;
 	if (pos != string::npos) {
 		opt = formatstr.substr(pos+1);
